Sidak.p.adjust: The adjusted p-values for Sidak single-step FWER controlling procedure.
Description
The function for calculating the adjusted p-values based on original available p-values.
Usage
Sidak.p.adjust(p, alpha, make.decision)
Arguments
p
numeric vector of p-values (possibly with NAs). Any other R is coerced by as.numeric. Same as in p.adjust.
alpha
significant level used to compare with adjusted p-values to make decisions, the default value is 0.05.
make.decision
logical; if TRUE, then the output include the decision rules compared adjusted p-values with significant level \(\alpha\)
Value
A numeric vector of the adjusted p-values (of the same length as p) if make.decision = FALSE, or a list including original p-values, adjusted p-values and decision rules if make.decision = TRUE.