Tarone.p.adjust: The adjusted p-values for Tarone's single-step FWER controlling procedure.
Description
The function for calculating the adjusted p-values based on original available p-values and all attaianble p-values.
Usage
Tarone.p.adjust(p, p.set, alpha, make.decision)
Arguments
p
numeric vector of p-values (possibly with NAs). Any other R is coerced by as.numeric. Same as in p.adjust.
p.set
a list of numeric vectors, where each vector is the vector of all attainable p-values containing the available p-value for the corresponding hypothesis.
alpha
significant level used to compare with adjusted p-values to make decisions, the default value is 0.05.
make.decision
logical; if TRUE, then the output include the decision rules compared adjusted p-values with significant level \(\alpha\)
Value
A numeric vector of the adjusted p-values (of the same length as p) if make.decision = FALSE, or a list including original p-values, adjusted p-values and decision rules if make.decision = TRUE.
References
Tarone, R. E. (1990).
A modified Bonferroni method for discrete data.
Biometrics, 46: 515-522.